@@ -25,9 +25,9 @@
 #include "core/volume.h"
 
 DBusControlWrapper::DBusControlWrapper(shared_ptr<MixDevice> parent, const QString& path)
-	: QObject(0)
+	: QObject(nullptr)
 {
-//	kDebug() << "QDBusConnection for control created" << path;
+//	qCDebug(KMIX_LOG) << "QDBusConnection for control created" << path;
 	m_md = parent;
 	new ControlAdaptor( this );
 	QDBusConnection::sessionBus().registerObject( path, this );
